@@ -31,6 +31,7 @@ import tempfile
 
 from gettext import gettext as _
 from threading import Thread
+from traceback import print_exc
 
 from softwareproperties.shortcuts import ShortcutException
 
@@ -388,7 +389,11 @@ class PPAShortcutHandler(object):
 def shortcut_handler(shortcut):
     if not shortcut.startswith("ppa:"):
         return None
-    return PPAShortcutHandler(shortcut)
+    try:
+        return PPAShortcutHandler(shortcut)
+    except ShortcutException:
+        print_exc()
+        return None
 
 
 if __name__ == "__main__":
